# Changelog

## [stormi-v0.2.0](https://github.com/pinellolab/stormi/compare/stormi-v0.1.3...stormi-v0.2.0) (2025-03-20)

### Features

* **logging:** add module to configure logger ([15a5c26](https://github.com/pinellolab/stormi/commit/15a5c261782ab851e0aef91567e78d6ed7edb231))
* **models:** add determinstic inference module ([f9f1f45](https://github.com/pinellolab/stormi/commit/f9f1f45c48c9a8e5047cec210e541b31b8552452))
* **models:** add determinstic simulation module ([22ac6dc](https://github.com/pinellolab/stormi/commit/22ac6dc3d471ddf71c3a874e3d5f525bf382f64d))
* **styles:** add configuration ([c223a9c](https://github.com/pinellolab/stormi/commit/c223a9c886e7822d4731164be1556f9f6aa1d77f))
* **styles:** add default mpl styles ([b04323c](https://github.com/pinellolab/stormi/commit/b04323cf1d0f2cbc4e162f477bc8cffe77a35044))

### Bug Fixes

* **models:** add package init ([f1f46af](https://github.com/pinellolab/stormi/commit/f1f46afde6ca7e46dc67ca149a7ecc21d7676fec))
